@@ -62,7 +62,7 @@ metaval <- function (object, method, estimate, ic)
 
 repCV <- function (object, k = 10)
 {
-  pred <- object$model$subX
+  pred <- object$model$X
   targ <- object$model$Y
   scaling <- object$metapls$scaling
   method <- object$method
@@ -97,4 +97,5 @@ repCV <- function (object, k = 10)
   cat (paste (' (sd: ', format (sd (rmsevec), digits = 3), ')  \n', sep = ''))
   
   invisible (result)     
-}
\ No newline at end of file
+}
+
